@@ -20,6 +20,9 @@ class Command(BaseCommand):
         make_option('-U', '--user', action='store',
                     dest='user', default=None,
                     help='Use another user for the database then defined in settings.py'),
+        make_option('-O', '--owner', action='store',
+                    dest='owner', default=None,
+                    help='Use another owner for creating the database then the user defined in settings or via --user'),
         make_option('-P', '--password', action='store',
                     dest='password', default=None,
                     help='Use another password for the database then defined in settings.py'),
@@ -39,6 +42,10 @@ class Command(BaseCommand):
         Note: Transaction wrappers are in reverse as a work around for
         autocommit, anybody know how to do this the right way?
         """
+
+        if args:
+            raise CommandError("reset_db takes no arguments")
+
         router = options.get('router')
         dbinfo = settings.DATABASES.get(router)
         if dbinfo is None:
@@ -47,6 +54,7 @@ class Command(BaseCommand):
         engine = dbinfo.get('ENGINE').split('.')[-1]
         user = options.get('user') or dbinfo.get('USER')
         password = options.get('password') or dbinfo.get('PASSWORD')
+        owner = options.get('owner') or user
 
         database_name = options.get('dbname') or dbinfo.get('NAME')
         if database_name == '':
@@ -130,11 +138,16 @@ Type 'yes' to continue, or 'no' to cancel: """ % (database_name,))
                 logging.info("Error: %s" % str(e))
 
             create_query = "CREATE DATABASE %s" % database_name
-            create_query += " WITH OWNER = %s " % user
+            if owner:
+                create_query += " WITH OWNER = \"%s\" " % owner
             create_query += " ENCODING = 'UTF8'"
 
             if engine == 'postgis':
-                create_query += ' TEMPLATE = template_postgis'
+                # fetch postgis template name if it exists
+                from django.contrib.gis.db.backends.postgis.creation import PostGISCreation
+                postgis_template = PostGISCreation(connection).template_postgis
+                if postgis_template is not None:
+                    create_query += ' TEMPLATE = %s' % postgis_template
 
             if settings.DEFAULT_TABLESPACE:
                 create_query += ' TABLESPACE = %s;' % settings.DEFAULT_TABLESPACE
